# Generated by roxygen2: do not edit by hand

export("%>%")
export("%m-%")
export(is_forecast)
export(is_observed)
export(plane_cover)
export(plane_diff)
export(plane_repeat)
export(plane_score)
export(plane_seed)
export(plane_shape)
export(plane_taper)
export(plane_trend)
export(plane_zero)
export(read_forecast)
export(rplanes_explorer)
export(to_signal)
export(valid_dates)
importFrom(lubridate,"%m-%")
importFrom(magrittr,"%>%")
importFrom(rlang,.data)
importFrom(rlang,.env)
importFrom(utils,tail)
