
<br>

<div class="alert alert-warning" role="alert">
  <strong>Data must be uploaded and analyzed to view "Scores" and "Raw Data" tab contents.</strong>
</div>

### Getting Started

1. Select the type of signal to be evaluated
2. Upload data to use for the plausibility analysis seed
3. Upload data containing the signal to be evaluated (or for an observed signal identify the number of points to evaluate)
4. Enter the resolution, outcome, and forecast horizon (if applicable)
5. Optionally modify default parameters used for analysis
6. Click "Analyze"

Note that the app also includes example forecast data to demonstrate usage and plausibility analysis output. 

For more information navigate to the "Help" tab.
